# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/beegees/page/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/beegees/page/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Beegees\\Page\\": "packages/beegees/page/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Beegees\Page\Providers\PageServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Page'  => Beegees\Page\Facades\Page::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Beegees\\PageTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Beegees\Page\Providers\PageServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Beegees\Page\Providers\PageServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Beegees\Page\Providers\PageServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/page/{modulename}

**User**

    http://path-to-route-folder/user/page/{modulename}

**Public**

    http://path-to-route-folder/pages


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/page/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/page/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/page/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/page/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/page/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/page/{modulename}/{slug}
    METHOD: GET