<?php

namespace Beegees\Page\Providers;

use Illuminate\Support\ServiceProvider;
use Beegees\Page\Page;

class PageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'page');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'page');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Beegees\Page\Providers\AuthServiceProvider::class);
        $this->app->register(\Beegees\Page\Providers\RouteServiceProvider::class);
        // $this->app->register(\Beegees\Page\Providers\EventServiceProvider::class);
        // $this->app->register(\Beegees\Page\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('beegees.page', function($app)
        {
            return $this->app->make(Page::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Blog to repository
        $this->app->bind(
            'Beegees\Page\Interfaces\BlogRepositoryInterface',
            \Beegees\Page\Repositories\Eloquent\BlogRepository::class
        );        // Bind Category to repository
        $this->app->bind(
            'Beegees\Page\Interfaces\CategoryRepositoryInterface',
            \Beegees\Page\Repositories\Eloquent\CategoryRepository::class
        );
    }


    /**
     * Merges user's and page's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'beegees.page'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Beegees\Page\Commands\Page::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['beegees.page'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('beegees/page.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/page')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/page')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
